@@ -1,6 +1,8 @@
-;; mailcrypt.el v3.4, mail encryption with PGP
+;; mailcrypt.el v3.5.6, mail encryption with PGP
 ;; Copyright (C) 1995  Jin Choi <jin@atype.com>
 ;;                     Patrick LoPresti <patl@lcs.mit.edu>
+;;           (C) 1998  Len Budney <lbudney@pobox.com>
+;;           (C) 2001  Brian Warner <warner@lothar.com>
 ;; Any comments or suggestions welcome.
 ;; Inspired by pgp.el, by Gray Watson <gray@antaire.com>.
 
@@ -32,6 +34,7 @@
 
 (require 'easymenu)
 (require 'comint)
+(require 'rfc822)
 
 (eval-and-compile
   (condition-case nil (require 'itimer) (error nil))
@@ -53,11 +56,15 @@
 (autoload 'mc-remailer-encrypt-for-chain "mc-remail" nil t)
 (autoload 'mc-remailer-insert-response-block "mc-remail" nil t)
 (autoload 'mc-remailer-insert-pseudonym "mc-remail" nil t)
+(autoload 'mc-setversion "mc-setversion" nil t)
 
 ;;}}}
 
 ;;{{{ Minor mode variables and functions
 
+(defvar mc-pgp-always-sign nil 
+  "*If t, always sign encrypted PGP messages, or never sign if 'never.")
+
 (defvar mc-read-mode nil
   "Non-nil means Mailcrypt read mode key bindings are available.")
 
@@ -197,7 +204,9 @@
 ;;}}}
 
 ;;{{{ User variables.
-(defconst mc-version "3.4")
+(defconst mc-version "3.5.6")
+(defvar mc-temp-directory "/tmp"
+  "*Default temp directory to be used by Mailcrypt.")
 (defvar mc-default-scheme 'mc-scheme-pgp "*Default encryption scheme to use.")
 (defvar mc-passwd-timeout 60
   "*Time to deactivate password in seconds after a use.
@@ -252,6 +261,8 @@ If 'never, always use a viewer instead of replacing.")
     (mh-folder-mode (decrypt . mc-mh-decrypt-message)
 		    (verify . mc-mh-verify-signature)
 		    (snarf . mc-mh-snarf-keys))
+    (message-mode (encrypt . mc-encrypt-message)
+                  (sign . mc-sign-message))
     (gnus-summary-mode (decrypt . mc-gnus-decrypt-message)
 		       (verify . mc-gnus-verify-signature)
 		       (snarf . mc-gnus-snarf-keys))
@@ -265,9 +276,7 @@ If 'never, always use a viewer instead of replacing.")
     (mh-letter-mode (encrypt . mc-encrypt-message)
 		    (sign . mc-sign-message))
     (news-reply-mode (encrypt . mc-encrypt-message)
-		     (sign . mc-sign-message))
-    (message-mode (encrypt . mc-encrypt-message)
-		  (sign . mc-sign-message)))
+		     (sign . mc-sign-message)))
 
   "Association list (indexed by major mode) of association lists
 (indexed by operation) of functions to call for each major mode.")
@@ -279,7 +288,10 @@ If 'never, always use a viewer instead of replacing.")
 
 (defvar mc-passwd-cache nil "Cache for passphrases.")
 
-(defvar mc-schemes '(("pgp" . mc-scheme-pgp)))
+(defvar mc-schemes '(("pgp50" . mc-scheme-pgp50)
+		     ("pgp" . mc-scheme-pgp)
+		     ("gpg" . mc-scheme-gpg)
+		     ))
 
 ;;}}}
 
@@ -337,7 +349,15 @@ stripping initial and trailing whitespace."
 ;	  (princ tmp))))))
 
 ;; In case I ever decide to do this right.
-(defconst mc-field-name-regexp "^\\(.+\\)")
+;; LRB - Thanks Pat! This helped a lot in updating mixmaster support.
+;; mc-field-name-regexp now catches precisely those email headers 
+;; which are RFC-822 compliant.
+(defconst mc-field-name-regexp 
+  (concat 
+   "^\\([" 
+   (char-to-string 33) "-" (char-to-string 57)
+   (char-to-string 59) "-" (char-to-string 126)
+   "]*\\)"))
 (defconst mc-field-body-regexp "\\(.*\\(\n[ \t].*\\)*\n\\)")
 
 (defun mc-get-fields (&optional matching bounds nuke)
@@ -379,7 +399,7 @@ Optional arg NUKE, if non-nil, means eliminate all fields returned."
 
 (defsubst mc-strip-address (addr)
   "Strip everything from ADDR except the basic Email address."
-  (car (cdr (mail-extract-address-components addr))))
+  (car (rfc822-addresses addr)))
 
 (defun mc-strip-addresses (addr-list)
   "Strip everything from the addresses in ADDR-LIST except the basic
@@ -387,7 +407,7 @@ Email address.  ADDR-LIST may be a single string or a list of strings."
   (if (not (listp addr-list)) (setq addr-list (list addr-list)))
   (setq addr-list
 	(mapcar
-	 (function (lambda (s) (mc-split "\\([ \t\n]*,[ \t\n]*\\)" s)))
+	 (function (lambda (s) (rfc822-addresses s)))
 	 addr-list))
   (setq addr-list (apply 'append addr-list))
   (mapconcat 'mc-strip-address addr-list ", "))
@@ -412,7 +432,7 @@ Email address.  ADDR-LIST may be a single string or a list of strings."
 		     (match-beginning 0) (match-end 0))
 		  (setq retval nil)
 		  default))))
-    (if msg (message "%s" msg))
+    (if msg (message-or-box "%s" msg))
     retval))
 
 (defun mc-process-region (beg end passwd program args parser &optional buffer)
@@ -528,4 +548,5 @@ Return the passphrase.  If PROMPT is nil, only return value if cached."
 (defalias 'mailcrypt-insert-public-key 'mc-insert-public-key)
 (defalias 'mailcrypt-snarf 'mc-snarf)
 ;;}}}
+
 (provide 'mailcrypt)
