@@ -3,7 +3,7 @@
 ;;                     Patrick LoPresti <patl@lcs.mit.edu>
 ;;               1998  Brian Warner <warner@lothar.com>
 
-;; $Id: mc-gpg.el,v 1.14 1999/10/07 05:23:46 budney Exp $
+;; $Id: mc-gpg.el,v 1.19 2001/09/26 06:36:00 warner Exp $
 
 ;;{{{ Licensing
 ;; This file is intended to be used with GNU Emacs.
@@ -74,7 +74,8 @@
 (defvar mc-gpg-alternate-keyring nil
   "*Public keyring to use instead of default.")
 (defvar mc-gpg-comment
-   (format "Processed by Mailcrypt %s and Gnu Privacy Guard <http://www.gnupg.org/>" mc-version)
+   (format "Processed by Mailcrypt %s <http://mailcrypt.sourceforge.net/>"
+	   mc-version)
   "*Comment field to appear in ASCII armor output.  If nil, let GPG use its 
 default.")
 (defconst mc-gpg-msg-begin-line "^-----BEGIN PGP MESSAGE-----\r?$"
@@ -89,11 +90,11 @@ default.")
   "Text for start of GPG public key.")
 (defconst mc-gpg-key-end-line "^-----END PGP PUBLIC KEY BLOCK-----\r?$"
   "Text for end of GPG public key.")
-(defconst mc-gpg-extra-args nil
+(defvar mc-gpg-extra-args nil
   "Extra arguments to pass to all invocations of gpg. Used during debugging to
 set --homedir, to use special test keys instead of the developer's normal
 keyring.")
-(defconst mc-gpg-debug-buffer nil
+(defvar mc-gpg-debug-buffer nil
   "A buffer for debugging messages. If nil, no debugging messages are logged.
 BEWARE! Sensitive data (including your passphrase) is put here. Set this with:
  (setq mc-gpg-debug-buffer (get-buffer-create \"mc debug\"))")
@@ -272,7 +273,8 @@ The value returned is the value of the last form in BODY."
       (delete-file stderr-tempfilename)
       (delete-file status-tempfilename)
       ;; kill off temporary buffers unless we're debugging
-      (if (not mc-gpg-debug-buffer)
+      (if (or (not (boundp 'mc-gpg-debug-buffer))
+	      (not mc-gpg-debug-buffer))
 	  (progn
 	    (if (get-buffer " *mailcrypt stdout temp")
 		(kill-buffer " *mailcrypt stdout temp"))
@@ -319,7 +321,7 @@ GPG ID.")
     (if (string= str "***** CONVENTIONAL *****") nil
       (let ((result (cdr-safe (assoc str mc-gpg-key-cache)))
 	    (key-regexp
-	     "^\\(sec\\|pub\\):[^:]*:[^:]*:[^:]*:\\([^:]*\\):[^:]*:[^:]*:[^:]*:[^:]*:\\([^:]*\\):$"
+	     "^\\(sec\\|pub\\):[^:]*:[^:]*:[^:]*:\\([^:]*\\):[^:]*:[^:]*:[^:]*:[^:]*:\\([^:]*\\):"
 	     )
 	    (obuf (current-buffer))
 	    buffer)
@@ -340,7 +342,11 @@ GPG ID.")
 		      (setq args (append mc-gpg-extra-args args)))
 		  (mc-gpg-debug-print 
 		   (format "lookup: args are %s" args))
-		  (apply 'call-process mc-gpg-path nil buffer nil args)
+		  (let ((coding-system-for-read 
+			 (if (and (fboundp 'coding-system-p)
+				  (coding-system-p 'utf-8))
+			     'utf-8 nil)))
+		    (apply 'call-process mc-gpg-path nil buffer nil args))
 		  (set-buffer buffer)
 		  (goto-char (point-min))
 		  (if (re-search-forward key-regexp nil t)
@@ -405,7 +411,12 @@ GPG ID.")
 	  )
       )
 
-    ; if we're supposed to encrypt for the user too, we need to know their key
+    ; if we're supposed to encrypt for the user too, we need their key
+    ;; FIXME: we only need their public key, not the secret one. Some users
+    ;; (the author included) keep their secret keys offline unless needed
+    ;; (but the public ones are still available).. the --list-secret-keys
+    ;; done by mc-gpg-lookup-key will fail in this situation. Change
+    ;; mc-gpg-lookup-key to have a way to look for public keys too.
     (if (and recipients mc-encrypt-for-me)
 	(setq recipients (cons (cdr (or key
 					(setq key (mc-gpg-lookup-key 
@@ -416,7 +427,7 @@ GPG ID.")
     (if recipients
 	(setq args (append (apply 'append 
 				  (mapcar '(lambda (x) 
-					     (list "--remote-user" 
+					     (list "--recipient" 
 						   (concat "\"" x "\""))) 
 					  recipients))
 			   args)))
