@@ -115,7 +115,7 @@ $remailer{\"NAME\"} = \"<EMAIL ADDRESS> PROPERTIES\";
 PROPERTIES is a space-separated set of strings.
 
 This format is named after Raphael Levien, who maintains a list of
-active remailers.  Do \"finger remailer-list@kiwi.cs.berkeley.edu\"
+active remailers.  Do \"finger rlist@publius.net\"
 for the latest copy of his list.")
 
 (defvar mc-remailer-user-chains nil
@@ -208,7 +208,7 @@ should not be included in this list.")
   (let (chains remailer remailer-name ranking)
     (while
 	(re-search-forward
-	 "^\\$remailer{\"\\(.+\\)\"}[ \t]*=[ \t]*\"\\(.*\\)\";"
+	 "^\\$remailer{['\"]\\(.+\\)['\"]}[ \t]*=[ \t]*['\"]\\(.*\\)['\"];"
 	 nil t)
       (let ((name (buffer-substring-no-properties
 		   (match-beginning 1) (match-end 1)))
@@ -244,7 +244,10 @@ should not be included in this list.")
       (if (not (null remailer))
 	  (setq chains (cons (list remailer-name remailer) chains))))
     (goto-char (point-min))
-    (if (re-search-forward "----------" nil t)
+    (if (re-search-forward "----------" nil t) ; Locate rankings at bottom
+	;; Read each word in the rankings section.  Each time we 
+	;; hit a remailer we've identified, append it to the ranking
+	;; list.  Thus we sort remailers according to rank.
 	(while (re-search-forward "^\\([a-zA-Z0-9\\-]+\\) " nil t)
 	  (setq remailer-name (buffer-substring-no-properties
 			       (match-beginning 1) (match-end 1)))
@@ -478,6 +481,9 @@ a description of Levien file format."
 	  (mapconcat 'identity regexps "\\)\\|\\(")
 	  "\\)"))
 
+; Quiet a warning message when the user hasn't set this.
+(defvar gnus-user-from-line nil)
+
 (defun mc-user-mail-address ()
   "Figure out the user's Email address as best we can."
   (mc-strip-address
@@ -599,6 +605,7 @@ be passed to this program for rewriting.")
 	(main-header (mc-find-main-header))
 	(colon-header (mc-find-colon-header))
 	(hash-header (mc-find-hash-header))
+        (newsgroups (mc-get-fields "Newsgroups" nil t))
 	recipients preserved newsgroups first last rest preserved-regexp)
 
     ;; Figure out FIRST and LAST. FIRST is the first Mixmaster in the
@@ -636,19 +643,27 @@ be passed to this program for rewriting.")
     (setq recipients
 	  (mc-cleanup-recipient-headers
 	   (mapconcat 'cdr (mc-get-fields "To" main-header t) ", ")))
-    (setq newsgroups (mc-get-fields "Newsgroups" nil t))
-    ;; Mixmaster does not support posting...
-;;;    (if (and newsgroups
-;;;	     (not (member "post" (mc-remailer-properties last))))
     (if newsgroups
+	(setq newsgroups 
+	  (mc-cleanup-recipient-headers
+	   (cdr 
+	    (assoc "Newsgroups" newsgroups)))))
+    ;; Mixmaster does not support posting...
+;    (if newsgroups
+    ;; Now they do! (1998)
+    (if (and newsgroups
+	     (not (member "post" (mc-remailer-properties last))))
 	(error "Remailer %s does not support posting"
 	       (mc-remailer-address last)))
     (setq
      recipients
      (append (mapcar
-	      (function (lambda (c) (concat "Post:" (cdr c)))) newsgroups)
+	      (function (lambda (c) (concat "Post: " c))) newsgroups)
 	     recipients))
 
+    (mapcar
+     (function (lambda (c) (message c))) recipients)
+
     (setq
      preserved-regexp
      (mc-disjunction-regexp (cons "Subject" mc-remailer-preserved-headers)))
