@@ -22,6 +22,7 @@
 ;;{{{ Load some required packages
 (require 'mailcrypt)
 (require 'mail-utils)
+(require 'rfc822)
 
 (eval-when-compile
   ;; RMAIL
@@ -36,6 +37,10 @@
 
   ;; GNUS
   (condition-case nil (require 'gnus) (error nil))
+  (autoload 'gnus-summary-select-article "gnus-sum")
+  (autoload 'gnus-summary-edit-article "gnus-sum")
+  (autoload 'gnus-summary-edit-article-postpone "gnus-sum")
+  (autoload 'gnus-summary-edit-article-done "gnus-sum")
 
   ;; MH-E
   (condition-case nil (require 'mh-e) (error nil)))
@@ -43,7 +48,9 @@
 (eval-and-compile
   (condition-case nil (require 'mailalias) (error nil)))
 
-(autoload 'mc-scheme-pgp "mc-pgp" nil t)
+(autoload 'mc-scheme-pgp   "mc-pgp"  nil t)
+(autoload 'mc-scheme-pgp50 "mc-pgp5" nil t)
+(autoload 'mc-scheme-gpg   "mc-gpg"  nil t)
 
 ;;}}}
 
@@ -54,7 +61,7 @@
   ;; assuming they were possibly extracted from the headers of a reply,
   ;; returns a list of the address components.
   (mapcar 'mc-strip-address
-	  (mc-split "\\([ \t\n]*,[ \t\n]*\\)+" str)))
+	  (rfc822-addresses str)))
 
 (defun mc-find-headers-end ()
   (save-excursion
@@ -178,8 +185,23 @@ Returns a pair (SUCCEEDED . VERIFIED) where SUCCEEDED is t if the encryption
 succeeded and VERIFIED is t if it had a valid signature."
   (save-excursion
     (let ((schemes mc-schemes)
-	  limits scheme)
-      (while (and schemes
+	  limits 
+	  (scheme mc-default-scheme))
+
+      ; Attempt to find a message signed according to the default
+      ; scheme.
+      (if mc-default-scheme
+	  (setq
+	   limits
+	   (mc-message-delimiter-positions
+	    (cdr (assoc 'msg-begin-line (funcall mc-default-scheme)))
+	    (cdr (assoc 'msg-end-line (funcall mc-default-scheme))))))
+
+      ; We can't find a message signed in the default scheme.
+      ; Step through all the schemes we know, trying to identify
+      ; the applicable one by examining headers.
+      (while (and (null limits)
+		  schemes
 		  (setq scheme (cdr (car schemes)))
 		  (not (setq
 			limits
@@ -276,8 +298,23 @@ Show the result as a message in the minibuffer. Returns t if the signature
 is verified."
   (save-excursion
     (let ((schemes mc-schemes)
-	  limits scheme)
-      (while (and schemes
+	  limits 
+	  (scheme mc-default-scheme))
+
+      ; Attempt to find a message signed according to the default
+      ; scheme.
+      (if mc-default-scheme
+	  (setq
+	   limits
+	   (mc-message-delimiter-positions
+	    (cdr (assoc 'signed-begin-line (funcall mc-default-scheme)))
+	    (cdr (assoc 'signed-end-line (funcall mc-default-scheme))))))
+
+      ; We can't find a message signed in the default scheme.
+      ; Step through all the schemes we know, trying to identify
+      ; the applicable one by examining headers.
+      (while (and (null limits)
+		  schemes
 		  (setq scheme (cdr (car schemes)))
 		  (not
 		   (setq
@@ -346,11 +383,26 @@ Exact behavior depends on current major mode."
   (let ((schemes mc-schemes)
 	(start (point-min))
 	(found 0)
-	limits scheme)
+	limits 
+	(scheme mc-default-scheme))
     (save-excursion
       (catch 'done
 	(while t
-	  (while (and schemes
+
+	  ; Attempt to find a message signed according to the default
+	  ; scheme.
+	  (if mc-default-scheme
+	      (setq
+	       limits
+	       (mc-message-delimiter-positions
+		(cdr (assoc 'key-begin-line (funcall mc-default-scheme)))
+		(cdr (assoc 'key-end-line (funcall mc-default-scheme)))
+		start)))
+	  ; We can't find a message signed in the default scheme.
+	  ; Step through all the schemes we know, trying to identify
+	  ; the applicable one by examining headers.
+	  (while (and (null limits)
+		      schemes
 		      (setq scheme (cdr (car schemes)))
 		      (not
 		       (setq
@@ -447,7 +499,10 @@ Exact behavior depends on current major mode."
 		   (rmail-mode)
 		   (use-local-map (copy-keymap (current-local-map)))
 		   (local-set-key "q" 'mc-rmail-view-quit)
-		   (set-buffer-modified-p nil)))))
+		   (set-buffer-modified-p nil)
+		   (rmail-add-label "decrypted")
+		   (if (cdr decryption-result)
+		       (rmail-add-label "verified"))))))
       (if (eq major-mode 'rmail-edit-mode)
 	  (rmail-abort-edit)))))
 
@@ -479,7 +534,7 @@ Exact behavior depends on current major mode."
 	from-line)
     (if (interactive-p)
 	(vm-follow-summary-cursor))
-    (vm-select-folder-buffer)
+;   (vm-select-folder-buffer) ;; TNX Eric C. Newton for commenting out.
     (vm-check-for-killed-summary)
     (vm-error-if-folder-read-only)
     (vm-error-if-folder-empty)
@@ -527,19 +582,20 @@ Exact behavior depends on current major mode."
 
 (defun mc-gnus-verify-signature ()
   (interactive)
-  (gnus-summary-select-article)
-  (gnus-eval-in-buffer-window gnus-article-buffer
+  (gnus-summary-select-article t)
+  (save-excursion
+    (set-buffer gnus-original-article-buffer)
     (save-restriction (widen) (mc-verify-signature))))
 
 (defun mc-gnus-snarf-keys ()
   (interactive)
-  (gnus-summary-select-article)
-  (gnus-eval-in-buffer-window gnus-article-buffer
+  (gnus-summary-select-article t)
+  (gnus-eval-in-buffer-window gnus-original-article-buffer
     (save-restriction (widen) (mc-snarf-keys))))
 
 (defun mc-gnus-decrypt-message ()
   (interactive)
-  (gnus-summary-select-article)
+  (gnus-summary-select-article t)
   ;; Gnus 5 has the string "Gnus" instead of "GNUS" in gnus-version.
   (if (not (let ((case-fold-search nil))
 	     (string-match "Gnus" gnus-version)))
@@ -565,6 +621,8 @@ Exact behavior depends on current major mode."
 
 ;;}}}		
 ;;{{{ MH
+(defvar mc-mh-backup-msg 3
+  "If 0, never back up MH messages.  If 3, always back up messages.")
 
 (defun mc-mh-decrypt-message ()
   "Decrypt the contents of the current MH message in the show buffer."
@@ -584,7 +642,7 @@ Exact behavior depends on current major mode."
 	    (set-buffer (create-file-buffer msg-filename))
 	    (insert-file-contents msg-filename t)
 	    (if (setq decrypt-okay (car (mc-decrypt-message)))
-		(save-buffer)
+		(save-buffer mc-mh-backup-msg)
 	      (message "Decryption failed.")
 	      (set-buffer-modified-p nil))
 	    (kill-buffer nil))
@@ -597,12 +655,12 @@ Exact behavior depends on current major mode."
 	  (mh-show msg))
       (mh-show msg)
       (save-excursion
-	(set-buffer mh-show-buffer)
-	(if (setq decrypt-okay (car (mc-decrypt-message)))
-	    (progn
-	      (goto-char (point-min))
-	      (set-buffer-modified-p nil))
-	  (message "Decryption failed.")))
+        (set-buffer mh-show-buffer)
+ 	  (if (setq decrypt-okay (car (mc-decrypt-message)))
+	      (progn
+		(goto-char (point-min))
+		(set-buffer-modified-p nil))
+            (message "Decryption failed.")))
       (if (not decrypt-okay)
 	  (progn
 	    (mh-invalidate-show-buffer)
